pub struct Win32_UserDesktop {
pub Element: Option<Win32_UserAccount>,
pub Setting: Option<Win32_Desktop>,
}Expand description
The Win32_UserDesktop association WMI class relates a user account and desktop settings that
are specific to it.
https://learn.microsoft.com/en-us/windows/win32/cimwin32prov/win32-userdesktop
Fields
Element: Option<Win32_UserAccount>Reference to the instance representing the user account whose desktop can be customized by the Settings property of this class.
Setting: Option<Win32_Desktop>Reference to the instance representing the desktop settings that serve to customize a specific user account desktop.