pub struct Win32_ShortcutFile {Show 34 fields
pub Caption: Option<String>,
pub Description: Option<String>,
pub InstallDate: Option<WMIDateTime>,
pub Status: Option<String>,
pub AccessMask: Option<u32>,
pub Archive: Option<bool>,
pub Compressed: Option<bool>,
pub CompressionMethod: Option<String>,
pub CreationClassName: Option<String>,
pub CreationDate: Option<WMIDateTime>,
pub CSCreationClassName: Option<String>,
pub CSName: Option<String>,
pub Drive: Option<String>,
pub EightDotThreeFileName: Option<String>,
pub Encrypted: Option<bool>,
pub EncryptionMethod: Option<String>,
pub Name: Option<String>,
pub Extension: Option<String>,
pub FileName: Option<String>,
pub FileSize: Option<u64>,
pub FileType: Option<String>,
pub FSCreationClassName: Option<String>,
pub FSName: Option<String>,
pub Hidden: Option<bool>,
pub InUseCount: Option<u64>,
pub LastAccessed: Option<WMIDateTime>,
pub LastModified: Option<WMIDateTime>,
pub Path: Option<String>,
pub Readable: Option<bool>,
pub System: Option<bool>,
pub Writeable: Option<bool>,
pub Manufacturer: Option<String>,
pub Version: Option<String>,
pub Target: Option<String>,
}Expand description
The Win32_ShortcutFile WMI class represents files that are shortcuts to other files,
directories, and commands.
https://learn.microsoft.com/en-us/windows/win32/cimwin32prov/win32-shortcutfile
Fields
Caption: Option<String>A short textual description of the object.
Description: Option<String>A textual description of the object.
InstallDate: Option<WMIDateTime>Indicates when the object was installed. Lack of a value does not indicate that the object is not installed.
Status: Option<String>String that indicates the current status of the object. Operational and non-operational status can be defined. Operational status can include “OK”, “Degraded”, and “Pred Fail”. “Pred Fail” indicates that an element is functioning properly, but is predicting a failure (for example, a SMART-enabled hard disk drive).
Non-operational status can include “Error”, “Starting”, “Stopping”, and “Service”. “Service” can apply during disk mirror-resilvering, reloading a user permissions list, or other administrative work. Not all such work is online, but the managed element is neither “OK” nor in one of the other states.
Values include the following:
- OK (“OK”)
- Error (“Error”)
- Degraded (“Degraded”)
- Unknown (“Unknown”)
- Pred Fail (“Pred Fail”)
- Starting (“Starting”)
- Stopping (“Stopping”)
- Service (“Service”)
- Stressed (“Stressed”)
- NonRecover (“NonRecover”)
- No Contact (“No Contact”)
- Lost Comm (“Lost Comm”)
AccessMask: Option<u32>Bitmask that represents the access rights required to access or perform specific operations on the directory. For bit values, see File and Directory Access Rights Constants.
Note: On FAT volumes, the FULL_ACCESS value is returned instead, which indicates no security has been set on the object.
- FILE_READ_DATA (file) or FILE_LIST_DIRECTORY (directory) (1): Grants the right to read data from the file. For a directory, this value grants the right to list the contents of the directory.
- FILE_WRITE_DATA (file) or FILE_ADD_FILE (directory) (2): Grants the right to write data to the file. For a directory, this value grants the right to create a file in the directory.
- FILE_APPEND_DATA (file) or FILE_ADD_SUBDIRECTORY (4): Grants the right to append data to the file. For a directory, this value grants the right to create a subdirectory.
- FILE_READ_EA (8): Grants the right to read extended attributes.
- FILE_WRITE_EA (16): Grants the right to write extended attributes.
- FILE_EXECUTE (file) or FILE_TRAVERSE (directory) (32): Grants the right to execute a file. For a directory, the directory can be traversed.
- FILE_DELETE_CHILD (directory) (64): Grants the right to delete a directory and all of the files it contains (its children), even if the files are read-only.
- FILE_READ_ATTRIBUTES (128): Grants the right to read file attributes.
- FILE_WRITE_ATTRIBUTES (256): Grants the right to change file attributes.
- DELETE (65536): Grants delete access.
- READ_CONTROL (131072): Grants read access to the security descriptor and owner.
- WRITE_DAC (262144): Grants write access to the discretionary ACL.
- WRITE_OWNER (524288): Assigns the write owner.
- SYNCHRONIZE (1048576): Synchronizes access and allows a process to wait for an object to enter the signaled state.
- ACCESS_SYSTEM_SECURITY (18809343): Controls the ability to get or set the SACL in an object’s security descriptor.
Archive: Option<bool>If True, the file should be archived.
Compressed: Option<bool>If True, the file is compressed.
CompressionMethod: Option<String>Free-form string that indicates the algorithm or tool used to compress the logical file. If the compression scheme is unknown or not described, use “Unknown”. If the logical file is compressed, but the compression scheme is unknown or not described, use “Compressed”. If the logical file is not compressed, use “Not Compressed”.
CreationClassName: Option<String>Name of the class.
CreationDate: Option<WMIDateTime>Date and time of the file’s creation.
CSCreationClassName: Option<String>Class of the computer system.
CSName: Option<String>Name of the computer system.
Drive: Option<String>Drive letter (including the colon that follows the drive letter) of the file.
Example: “c:”
EightDotThreeFileName: Option<String>File name in 8.3 format.
Example: “c:\progra~1”
Encrypted: Option<bool>If True, the file is encrypted.
EncryptionMethod: Option<String>Free-form string that identifies the algorithm or tool used to encrypt a logical file. If the encryption scheme is not indulged (for security reasons, for example), use “Unknown”. If the file is encrypted, but either its encryption scheme is unknown or not disclosed, use “Encrypted”. If the logical file is not encrypted, use “Not Encrypted”.
Name: Option<String>The Name property is a string representing the inherited name that serves as a key of a logical file instance within a file system. Full path names should be provided.
Example: C:\Windows\system\win.ini
Extension: Option<String>File name extension without the preceding period (dot).
Example: “txt”, “mof”, “mdb”
FileName: Option<String>File name without the file name extension.
Example: “MyDataFile”
FileSize: Option<u64>Size of the file, in bytes.
FileType: Option<String>Descriptor that represents the file type indicated by the Extension property.
FSCreationClassName: Option<String>Class of the file system.
FSName: Option<String>Name of the file system.
Hidden: Option<bool>If True, the file is hidden.
InUseCount: Option<u64>Number of “file opens” that are currently active against the file.
LastAccessed: Option<WMIDateTime>Date and time the file was last accessed.
LastModified: Option<WMIDateTime>Date and time the file was last modified.
Path: Option<String>Path of the file including the leading and trailing backslashes.
Example: “\windows\system"
Readable: Option<bool>If True, the file can be read.
System: Option<bool>If True, the file is a system file.
Writeable: Option<bool>If True, the file can be written.
Manufacturer: Option<String>Manufacturer string from the version resource (if one is present).
Version: Option<String>Version string from the version resource (if one is present).
Target: Option<String>Name of the object that this is a shortcut to.