pub struct Win32_CodecFile {Show 34 fields
pub AccessMask: Option<u32>,
pub Archive: Option<bool>,
pub Caption: Option<String>,
pub Compressed: Option<bool>,
pub CompressionMethod: Option<String>,
pub CreationClassName: Option<String>,
pub CreationDate: Option<WMIDateTime>,
pub CSCreationClassName: Option<String>,
pub CSName: Option<String>,
pub Description: Option<String>,
pub Drive: Option<String>,
pub EightDotThreeFileName: Option<String>,
pub Encrypted: Option<bool>,
pub EncryptionMethod: Option<String>,
pub Extension: Option<String>,
pub FileName: Option<String>,
pub FileSize: Option<u64>,
pub FileType: Option<String>,
pub FSCreationClassName: Option<String>,
pub FSName: Option<String>,
pub Group: Option<String>,
pub Hidden: Option<bool>,
pub InstallDate: Option<WMIDateTime>,
pub InUseCount: Option<u64>,
pub LastAccessed: Option<WMIDateTime>,
pub LastModified: Option<WMIDateTime>,
pub Manufacturer: Option<String>,
pub Name: Option<String>,
pub Path: Option<String>,
pub Readable: Option<bool>,
pub Status: Option<String>,
pub System: Option<bool>,
pub Version: Option<String>,
pub Writeable: Option<bool>,
}Expand description
The Win32_CodecFile WMI class represents the audio or video codec installed on the computer
system. Codecs convert one media format type to another, typically a compressed format to an
uncompressed format. The name “codec” is derived from a combination of compress and decompress.
For example, a codec can convert a compressed format, such as MS-ADPCM, to an uncompressed
format such as PCM, which most audio hardware can play directly.
https://learn.microsoft.com/en-us/windows/win32/cimwin32prov/win32-codecfile
Fields
AccessMask: Option<u32>Bitmask that represents the access rights required to access or perform specific operations on the codec file. For bit values, see File and Directory Access Rights Constants.
Note: On FAT volumes, the FULL_ACCESS value is returned instead, which indicates no security has been set on the object.
FILE_READ_DATA (file) or FILE_LIST_DIRECTORY (directory) (1)
FILE_WRITE_DATA (file) or FILE_ADD_FILE (directory) (2)
FILE_APPEND_DATA (file) or FILE_ADD_SUBDIRECTORY (directory) (4)
FILE_READ_EA (8)
FILE_WRITE_EA (16)
FILE_EXECUTE (file) or FILE_TRAVERSE (directory) (32)
FILE_DELETE_CHILD (directory) (64)
FILE_READ_ATTRIBUTES (128)
FILE_WRITE_ATTRIBUTES (256)
DELETE (65536)
READ_CONTROL (131072)
WRITE_DAC (262144)
WRITE_OWNER (524288)
SYNCHRONIZE (1048576)
Archive: Option<bool>If True, the file should be archived.
Caption: Option<String>Short description of the object.
Compressed: Option<bool>If True, the file is compressed.
CompressionMethod: Option<String>Algorithm or tool used to compress the logical file. If it is not possible (or not desired) to describe the compression scheme (perhaps because it is not known), use the following words: “Unknown” to represent that it is not known whether the logical file is compressed or not; “Compressed” to represent that the file is compressed but either its compression scheme is not known or not disclosed; and “Not Compressed” to represent that the logical file is not compressed.
CreationClassName: Option<String>Name of the first concrete class to appear in the inheritance chain used in the creation of an instance. When used with the other key properties of the class, the property allows all instances of this class and its subclasses to be uniquely identified.
CreationDate: Option<WMIDateTime>File creation date.
CSCreationClassName: Option<String>Class of the computer system.
CSName: Option<String>String representing the name of the computer system.
Description: Option<String>Full name of the codec driver. This string is intended to be displayed in large (descriptive) spaces.
Example: “Microsoft PCM Converter”
Drive: Option<String>Drive letter (including colon) of the file.
Example: “c:”
EightDotThreeFileName: Option<String>DOS-compatible file name for this file.
Example: “c:\progra~1”
Encrypted: Option<bool>If True, the file is encrypted.
EncryptionMethod: Option<String>Algorithm or tool used to encrypt the logical file. If it is not possible (or not desired) to describe the encryption scheme (perhaps for security reasons), use the following words: “Unknown” to represent that it is not known whether the logical file is encrypted or not; “Encrypted” to represent that the file is encrypted but either its encryption scheme is not known or not disclosed; and “Not Encrypted” to represent that the logical file is not encrypted.
Extension: Option<String>File name extension (without the dot).
Examples: “txt”, “mof”, “mdb”
FileName: Option<String>Name (without the extension) of the file.
Example: “autoexec”
FileSize: Option<u64>Size of the file (in bytes).
FileType: Option<String>File type (indicated by the Extension property).
FSCreationClassName: Option<String>Class of the file system.
FSName: Option<String>Name of the file system.
Group: Option<String>Codec represented by this class.
The values are:
- “Audio”
- “Video”
Audio (“Audio”)
Video (“Video”)
Hidden: Option<bool>If True, the file is hidden.
InstallDate: Option<WMIDateTime>Object was installed. This property does not require a value to indicate that the object is installed.
InUseCount: Option<u64>Number of “file opens” that are currently active against the file.
LastAccessed: Option<WMIDateTime>File was last accessed.
LastModified: Option<WMIDateTime>File was last modified.
Manufacturer: Option<String>Manufacturer string from version resource, if one is present.
Name: Option<String>Inherited name that serves as a key of a logical file instance within a file system. Full path names should be provided.
Example: “C:\Windows\system\win.ini”
Path: Option<String>Path of the file. This includes leading and trailing backslashes.
Example: “\windows\system"
Readable: Option<bool>File can be read.
Status: Option<String>Current status of the object. Various operational and nonoperational statuses can be defined. Operational statuses include: “OK”, “Degraded”, and “Pred Fail” (an element, such as a SMART-enabled hard disk drive, may be functioning properly but predicting a failure in the near future). Nonoperational statuses include: “Error”, “Starting”, “Stopping”, and “Service”. The latter, “Service”, could apply during mirror-resilvering of a disk, reload of a user permissions list, or other administrative work. Not all such work is online, yet the managed element is neither “OK” nor in one of the other states.
Values include the following:
OK(“OK”)Error(“Error”)Degraded(“Degraded”)Unknown(“Unknown”)Pred Fail(“Pred Fail”)Starting(“Starting”)Stopping(“Stopping”)Service(“Service”)Stressed(“Stressed”)NonRecover(“NonRecover”)No Contact(“No Contact”)Lost Comm(“Lost Comm”)
System: Option<bool>If True, the file is a system file.
Version: Option<String>Version string from version resource, if one is present.
Writeable: Option<bool>If True, the file can be written.