pub struct Win32_Process {Show 45 fields
pub CreationClassName: Option<String>,
pub Caption: Option<String>,
pub CommandLine: Option<String>,
pub CreationDate: Option<WMIDateTime>,
pub CSCreationClassName: Option<String>,
pub CSName: Option<String>,
pub Description: Option<String>,
pub ExecutablePath: Option<String>,
pub ExecutionState: Option<u16>,
pub Handle: Option<String>,
pub HandleCount: Option<u32>,
pub InstallDate: Option<WMIDateTime>,
pub KernelModeTime: Option<u64>,
pub MaximumWorkingSetSize: Option<u32>,
pub MinimumWorkingSetSize: Option<u32>,
pub Name: Option<String>,
pub OSCreationClassName: Option<String>,
pub OSName: Option<String>,
pub OtherOperationCount: Option<u64>,
pub OtherTransferCount: Option<u64>,
pub PageFaults: Option<u32>,
pub PageFileUsage: Option<u32>,
pub ParentProcessId: Option<u32>,
pub PeakPageFileUsage: Option<u32>,
pub PeakVirtualSize: Option<u64>,
pub PeakWorkingSetSize: Option<u32>,
pub Priority: Option<u32>,
pub PrivatePageCount: Option<u64>,
pub ProcessId: Option<u32>,
pub QuotaNonPagedPoolUsage: Option<u32>,
pub QuotaPagedPoolUsage: Option<u32>,
pub QuotaPeakNonPagedPoolUsage: Option<u32>,
pub QuotaPeakPagedPoolUsage: Option<u32>,
pub ReadOperationCount: Option<u64>,
pub ReadTransferCount: Option<u64>,
pub SessionId: Option<u32>,
pub Status: Option<String>,
pub TerminationDate: Option<WMIDateTime>,
pub ThreadCount: Option<u32>,
pub UserModeTime: Option<u64>,
pub VirtualSize: Option<u64>,
pub WindowsVersion: Option<String>,
pub WorkingSetSize: Option<u64>,
pub WriteOperationCount: Option<u64>,
pub WriteTransferCount: Option<u64>,
}Expand description
The Win32_Process WMI class represents a process on an operating system.
https://learn.microsoft.com/en-us/windows/win32/cimwin32prov/win32-process
Fields
CreationClassName: Option<String>Name of the class or subclass used in the creation of an instance. When used with other key properties of the class, this property allows all instances of the class and its subclasses to be uniquely identified.
Caption: Option<String>Short description of an object—a one-line string.
CommandLine: Option<String>Command line used to start a specific process, if applicable.
CreationDate: Option<WMIDateTime>Date the process begins executing.
CSCreationClassName: Option<String>Creation class name of the scoping computer system.
CSName: Option<String>Name of the scoping computer system.
Description: Option<String>Description of an object.
ExecutablePath: Option<String>Path to the executable file of the process.
Example: “C:\Windows\System\Explorer.Exe”
ExecutionState: Option<u16>Current operating condition of the process.
- Unknown (0)
- Other (1)
- Ready (2)
- Running (3)
- Blocked (4)
- Suspended Blocked (5)
- Suspended Ready (6)
- Terminated (7)
- Stopped (8)
- Growing (9)
Handle: Option<String>Process identifier.
HandleCount: Option<u32>Total number of open handles owned by the process. HandleCount is the sum of the handles currently open by each thread in this process. A handle is used to examine or modify the system resources. Each handle has an entry in a table that is maintained internally. Entries contain the addresses of the resources and data to identify the resource type.
InstallDate: Option<WMIDateTime>Date an object is installed. The object may be installed without a value being written to this property.
KernelModeTime: Option<u64>Time in kernel mode, in milliseconds. If this information is not available, use a value of 0 (zero).
MaximumWorkingSetSize: Option<u32>Maximum working set size of the process. The working set of a process is the set of memory pages visible to the process in physical RAM. These pages are resident, and available for an application to use without triggering a page fault.
Example: 1413120
MinimumWorkingSetSize: Option<u32>Minimum working set size of the process. The working set of a process is the set of memory pages visible to the process in physical RAM. These pages are resident and available for an application to use without triggering a page fault.
Example: 20480
Name: Option<String>Name of the executable file responsible for the process, equivalent to the Image Name property in Task Manager.
When inherited by a subclass, the property can be overridden to be a key property. The name is hard-coded into the application itself and is not affected by changing the file name. For example, even if you rename Calc.exe, the name Calc.exe will still appear in Task Manager and in any WMI scripts that retrieve the process name.
OSCreationClassName: Option<String>Creation class name of the scoping operating system.
OSName: Option<String>Name of the scoping operating system.
OtherOperationCount: Option<u64>Number of I/O operations performed that are not read or write operations.
OtherTransferCount: Option<u64>Amount of data transferred during operations that are not read or write operations.
PageFaults: Option<u32>Number of page faults that a process generates.
Example: 10
PageFileUsage: Option<u32>Amount of page file space that a process is using currently. This value is consistent with the VMSize value in TaskMgr.exe.
Example: 102435
ParentProcessId: Option<u32>Unique identifier of the process that creates a process. Process identifier numbers are
reused, so they only identify a process for the lifetime of that process. It is possible
that the process identified by ParentProcessId is terminated, so ParentProcessId may not
refer to a running process. It is also possible that ParentProcessId incorrectly refers to
a process that reuses a process identifier. You can use the CreationDate property to
determine whether the specified parent was created after the process represented by this
Win32_Process instance was created.
PeakPageFileUsage: Option<u32>Maximum amount of page file space used during the life of a process.
Example: 102367
PeakVirtualSize: Option<u64>Maximum virtual address space a process uses at any one time. Using virtual address space does not necessarily imply corresponding use of either disk or main memory pages. However, virtual space is finite, and by using too much the process might not be able to load libraries.
PeakWorkingSetSize: Option<u32>Peak working set size of a process.
Example: 1413120
Priority: Option<u32>Scheduling priority of a process within an operating system. The higher the value, the higher priority a process receives. Priority values can range from 0 (zero), which is the lowest priority to 31, which is highest priority.
Example: 7
PrivatePageCount: Option<u64>Current number of pages allocated that are only accessible to the process represented by
this Win32_Process instance.
ProcessId: Option<u32>Numeric identifier used to distinguish one process from another. ProcessIDs are valid from process creation time to process termination. Upon termination, that same numeric identifier can be applied to a new process.
This means that you cannot use ProcessID alone to monitor a particular process. For example,
an application could have a ProcessID of 7, and then fail. When a new process is started,
the new process could be assigned ProcessID 7. A script that checked only for a specified
ProcessID could thus be “fooled” into thinking that the original application was still
running.
QuotaNonPagedPoolUsage: Option<u32>Quota amount of nonpaged pool usage for a process.
Example: 15
QuotaPagedPoolUsage: Option<u32>Quota amount of paged pool usage for a process.
Example: 22
QuotaPeakNonPagedPoolUsage: Option<u32>Peak quota amount of nonpaged pool usage for a process.
Example: 31
QuotaPeakPagedPoolUsage: Option<u32>Peak quota amount of paged pool usage for a process.
Example: 31
ReadOperationCount: Option<u64>Number of read operations performed.
ReadTransferCount: Option<u64>Amount of data read.
SessionId: Option<u32>Unique identifier that an operating system generates when a session is created. A session spans a period of time from logon until logoff from a specific system.
Status: Option<String>This property is not implemented and does not get populated for any instance of this class. It is always NULL.
TerminationDate: Option<WMIDateTime>Process was stopped or terminated. To get the termination time, a handle to the process must be held open. Otherwise, this property returns NULL.
ThreadCount: Option<u32>Number of active threads in a process. An instruction is the basic unit of execution in a processor, and a thread is the object that executes an instruction. Each running process has at least one thread.
UserModeTime: Option<u64>Time in user mode, in 100 nanosecond units. If this information is not available, use a value of 0 (zero).
VirtualSize: Option<u64>Current size of the virtual address space that a process is using, not the physical or virtual memory actually used by the process. Using virtual address space does not necessarily imply corresponding use of either disk or main memory pages. Virtual space is finite, and by using too much, the process might not be able to load libraries. This value is consistent with what you see in Perfmon.exe.
WindowsVersion: Option<String>Version of Windows in which the process is running.
Example: 4.0
WorkingSetSize: Option<u64>Amount of memory in bytes that a process needs to execute efficiently—for an operating system that uses page-based memory management. If the system does not have enough memory (less than the working set size), thrashing occurs. If the size of the working set is not known, use NULL or 0 (zero). If working set data is provided, you can monitor the information to understand the changing memory requirements of a process.
WriteOperationCount: Option<u64>Number of write operations performed.
WriteTransferCount: Option<u64>Amount of data written.