Win32_ShadowCopy

Struct Win32_ShadowCopy 

pub struct Win32_ShadowCopy {
Show 27 fields pub Caption: Option<String>, pub Description: Option<String>, pub ID: Option<String>, pub InstallDate: Option<WMIDateTime>, pub Name: Option<String>, pub SetID: Option<String>, pub ProviderID: Option<String>, pub Status: Option<String>, pub Count: Option<u32>, pub DeviceObject: Option<String>, pub VolumeName: Option<String>, pub OriginatingMachine: Option<String>, pub ServiceMachine: Option<String>, pub ExposedName: Option<String>, pub State: Option<u32>, pub Persistent: Option<bool>, pub ClientAccessible: Option<bool>, pub NoAutoRelease: Option<bool>, pub NoWriters: Option<bool>, pub Transportable: Option<bool>, pub NotSurfaced: Option<bool>, pub HardwareAssisted: Option<bool>, pub Differential: Option<bool>, pub Plex: Option<bool>, pub Imported: Option<bool>, pub ExposedRemotely: Option<bool>, pub ExposedLocally: Option<bool>,
}
The Win32_ShadowCopy class is a storage extent that represents a duplicate copy of the original volume at a previous time.

https://learn.microsoft.com/en-us/previous-versions/windows/desktop/legacy/aa394428(v=vs.85)

Fields

Caption: Option<String>

Short textual description of the object.

Description: Option<String>

Textual description of the object.

ID: Option<String>

Unique identifier for a shadow copy on the system.

InstallDate: Option<WMIDateTime>

Date and time the object was installed. This property does not need a value to indicate that the object is installed.

Name: Option<String>

Label by which the object is known. When subclassed, this property can be overridden to be a key property.

SetID: Option<String>

Unique identifier for a shadow copy set to which the shadow belongs.

ProviderID: Option<String>

Unique identifier for a shadow provider that creates a shadow.

Status: Option<String>

Current status of the object.

Values include the following:

  • “OK”
  • “Error”
  • “Degraded”
  • “Unknown”
  • “Pred Fail”
  • “Starting”
  • “Stopping”
  • “Service”
  • “Stressed”
  • “NonRecover”
  • “No Contact”
  • “Lost Comm”
Count: Option<u32>

Number of shadow copies in a shadow copy set to which a shadow copy belongs.

DeviceObject: Option<String>

Windows object manager name for an underlying storage device that supports the original volume.

VolumeName: Option<String>

Name of the original volume for which a shadow copy is made.

OriginatingMachine: Option<String>

Name of the computer that hosts the original volume.

ServiceMachine: Option<String>

Name of the computer that services the shadow copy.

ExposedName: Option<String>

File system name of a shadow copy when it is exposed. The ExposedName property might contain a drive letter or mount point. The ExposedName property is NULL when a shadow copy is hidden or otherwise not exposed.

State: Option<u32>

Current state of a shadow copy.

Value: Meaning

  • 0: Unknown
  • 1: Preparing
  • 2: ProcessingPrepare
  • 3: Prepared
  • 4: ProcessingPrecommit
  • 5: Precommitted
  • 6: ProcessingCommit
  • 7: Committed
  • 8: ProcessingPostcommit
  • 9: Created
  • 10: Aborted
  • 11: Deleted
  • 12: Count
Persistent: Option<bool>

If true, the shadow copy is persistent across reboots.

ClientAccessible: Option<bool>

If true, the shadow copy is created by the Windows Previous Versions component.

NoAutoRelease: Option<bool>

If true, the shadow copy is retained after the requestor process ends. If false, the shadow copy is automatically deleted when the requestor process ends.

NoWriters: Option<bool>

If true, the shadow copy is created with the involvement of the shadow copy writer components.

Transportable: Option<bool>

If true, the shadow copy can be surfaced on another computer. If false, and the volumes are surfaced locally, it may not be possible to surface them later on a different computer.

NotSurfaced: Option<bool>

If true, the shadow copy is not currently in the device namespace of a local computer.

HardwareAssisted: Option<bool>

If true, the shadow copy is created by a hardware shadow copy provider.

Differential: Option<bool>

If true, the shadow copy is created by a differential shadow copy provider. The provider can be implemented in hardware or software.

Plex: Option<bool>

If true, the shadow copy is created by a split mirror shadow copy provider. The provider can be implemented in hardware or software.

Imported: Option<bool>

If true, the shadow copy is imported to a computer by using the Import method and is not created by using the Create method.

ExposedRemotely: Option<bool>

If true, the shadow copy is exposed on a remote computer with a network share. If ExposedRemotely and ExposedLocally are not set, the shadow copy is hidden.

ExposedLocally: Option<bool>

If true, the shadow copy is exposed on the local computer with a drive letter or mount point. If ExposedLocally and ExposedRemotely are not set, the shadow copy is hidden.