pub struct SoftwareLicensingService {Show 30 fields
pub Version: Option<String>,
pub KeyManagementServiceMachine: Option<String>,
pub IsKeyManagementServiceMachine: Option<u32>,
pub VLActivationInterval: Option<u32>,
pub VLRenewalInterval: Option<u32>,
pub KeyManagementServiceCurrentCount: Option<u32>,
pub RequiredClientCount: Option<u32>,
pub KeyManagementServiceProductKeyID: Option<String>,
pub DiscoveredKeyManagementServiceMachineName: Option<String>,
pub DiscoveredKeyManagementServiceMachinePort: Option<u32>,
pub PolicyCacheRefreshRequired: Option<u32>,
pub ClientMachineID: Option<String>,
pub RemainingWindowsReArmCount: Option<u32>,
pub KeyManagementServiceListeningPort: Option<u32>,
pub KeyManagementServiceDnsPublishing: Option<bool>,
pub KeyManagementServiceLowPriority: Option<bool>,
pub KeyManagementServiceHostCaching: Option<bool>,
pub KeyManagementServiceUnlicensedRequests: Option<u32>,
pub KeyManagementServiceLicensedRequests: Option<u32>,
pub KeyManagementServiceOOBGraceRequests: Option<u32>,
pub KeyManagementServiceOOTGraceRequests: Option<u32>,
pub KeyManagementServiceNonGenuineGraceRequests: Option<u32>,
pub KeyManagementServiceTotalRequests: Option<u32>,
pub KeyManagementServiceFailedRequests: Option<u32>,
pub KeyManagementServiceNotificationRequests: Option<u32>,
pub TokenActivationILID: Option<String>,
pub TokenActivationILVID: Option<u32>,
pub TokenActivationGrantNumber: Option<u32>,
pub TokenActivationCertificateThumbprint: Option<String>,
pub TokenActivationAdditionalInfo: Option<String>,
}Expand description
This class exposes the product-independent properties and methods of the Software Licensing service.
https://learn.microsoft.com/en-gb/previous-versions/windows/desktop/sppwmi/softwarelicensingservice
Fields
Version: Option<String>Specifies the version of the Software Licensing service.
KeyManagementServiceMachine: Option<String>Specifies the registered key management service machine name. Returns null if
SetKeyManagementServiceMachine has not been called.
IsKeyManagementServiceMachine: Option<u32>Indicates whether the machine has a key management service (KMS) enabled. The following values are possible.
Value: Description
- 0: False
- 1: True
VLActivationInterval: Option<u32>Specifies the frequency, in minutes, of how often a client should contact the KMS machine before the client is licensed.
VLRenewalInterval: Option<u32>Specifies the frequency, in minutes, of how often the current machine should contact the KMS machine after the client is licensed.
KeyManagementServiceCurrentCount: Option<u32>Specifies the count of currently active volume clients. A value of -1 indicates that the machine is not enabled as a KMS or that it has not received any client licensing-requests.
RequiredClientCount: Option<u32>Specifies the minimum number of clients required to connect to a KMS machine to enable volume licensing.
KeyManagementServiceProductKeyID: Option<String>Specifies the KMS product key ID. Returns null if not applicable.
DiscoveredKeyManagementServiceMachineName: Option<String>Specifies the last discovered KMS host name through DNS.
DiscoveredKeyManagementServiceMachinePort: Option<u32>Specifies the last discovered KMS host port through DNS.
PolicyCacheRefreshRequired: Option<u32>Indicates whether the licensing policy cache needs to be updated. The following values are possible.
Value: Description
- 0: Refresh not required.
- 1: Refresh required.
ClientMachineID: Option<String>Specifies the unique identifier for this volume client machine. The client includes this CMID in requests it sends to the KMS.
RemainingWindowsReArmCount: Option<u32>Specifies the remaining number of times that the client can be successfully rearmed.
KeyManagementServiceListeningPort: Option<u32>Specifies the TCP port on which the KMS host listens for activation requests.
KeyManagementServiceDnsPublishing: Option<bool>Indicates the DNS publishing status of a KMS host. The following values are possible.
Value: Description
- 0: Disabled
- 1: Auto-publish enabled (default)
KeyManagementServiceLowPriority: Option<bool>Indicates the thread priority status of the KMS. The following values are possible.
Value: Description
- 0: Normal priority (default)
- 1: Low priority
KeyManagementServiceHostCaching: Option<bool>Indicates the caching status of the KMS host name and port. The following values are possible.
Value: Description
- 0: Caching disabled
- 1: Caching enabled (default)
KeyManagementServiceUnlicensedRequests: Option<u32>Specifies the count of KMS requests from clients with LicenseStatus set to 0 (Unlicensed).
KeyManagementServiceLicensedRequests: Option<u32>Specifies the count of KMS requests from clients with LicenseStatus set to 1 (Licensed).
KeyManagementServiceOOBGraceRequests: Option<u32>Specifies the count of KMS requests from clients with LicenseStatus set to 2 (OOBGrace).
KeyManagementServiceOOTGraceRequests: Option<u32>Specifies the count of KMS requests from clients with LicenseStatus set to 3 (OOTGrace).
KeyManagementServiceNonGenuineGraceRequests: Option<u32>Specifies the count of KMS requests from clients with LicenseStatus set to 4 (NonGenuineGrace).
KeyManagementServiceTotalRequests: Option<u32>Specifies the total count of valid KMS requests.
KeyManagementServiceFailedRequests: Option<u32>Specifies the total count of failed KMS requests.
KeyManagementServiceNotificationRequests: Option<u32>Specifies the count of KMS requests from clients with LicenseStatus set to 5 (Notification).
TokenActivationILID: Option<String>Specifies the ID of the token-based activation license that activated the computer.
TokenActivationILVID: Option<u32>Specifies the version of the token-based activation license that activated the computer.
TokenActivationGrantNumber: Option<u32>Specifies the grant number in the token-based activation license that activated the computer.
TokenActivationCertificateThumbprint: Option<String>Specifies the thumbprint of the certificate that activated the computer.
TokenActivationAdditionalInfo: Option<String>Specifies additional information for token-based activation.