pub struct Win32_ShadowProvider {
pub ID: Option<String>,
pub Name: Option<String>,
pub CLSID: Option<String>,
pub Type: Option<u32>,
pub Version: Option<String>,
pub VersionID: Option<String>,
}Expand description
Typically, the Win32_ShadowProvider class represents a component that is a combination of user-mode
and kernel or firmware implementation, that creates and represents volume shadow copies.
https://learn.microsoft.com/en-us/previous-versions/windows/desktop/vsswmi/win32-shadowprovider
Fields
ID: Option<String>Uniquely identifies the shadow provider on a system.
Name: Option<String>Descriptive name of a provider.
CLSID: Option<String>Common Object Model (COM) class ID registered for a shadow provider.
Type: Option<u32>Specifies the class to which a shadow provider belongs.
Possible values:
Value: Meaning
- 0: Unknown
- 1: System
- 2: Software
- 3: Hardware
Version: Option<String>Text representation of a shadow provider version.
VersionID: Option<String>Numeric representation of a shadow provider version.